@@ -161,13 +161,13 @@ class AbstractRetrieval(Retrieval):
         """Date range of the conference the document belongs to represented
         by two tuples in the form (YYYY, MM, DD).
         """
-        date = self._confevent.get('confdate', {})
-        if len(date) > 0:
-            start = {k: int(v) for k, v in date['startdate'].items()}
-            end = {k: int(v) for k, v in date['enddate'].items()}
-            return ((start['@year'], start['@month'], start['@day']),
-                    (end['@year'], end['@month'], end['@day']))
-        else:
+        dates = self._confevent.get('confdate', {})
+        try:
+            keys = ("startdate", "enddate")
+            date_order = ("@year", "@month", "@day")
+            d = (tuple(int(dates[k1][k2]) for k2 in date_order) for k1 in keys)
+            return tuple(d)
+        except KeyError:
             return None
 
     @property
@@ -380,13 +380,12 @@ class AbstractRetrieval(Retrieval):
     @property
     def refcount(self):
         """Number of references of an article.
-        Note: Requires the FULL view of the article.
+        Note: Requires either the FULL view or REF view.
         """
-        if self._view == "REF":
-            path = ["references", '@total-references']
-        else:
-            path = ['item', 'bibrecord', 'tail', 'bibliography', '@refcount']
-        return chained_get(self._json, path)
+        try:  # REF view
+            return self._ref['@total-references']
+        except KeyError:  # FULL view
+            return self._ref.get('@refcount')
 
     @property
     def references(self):
@@ -409,21 +408,18 @@ class AbstractRetrieval(Retrieval):
         Scopus-provided information on the publication, `fulltext` is the text
         the authors used for the reference.
 
-        Note: Requires either the FULL view or REF view of the article.  Might
-        be empty even if refcount is positive.  Specific fields can be empty.
+        Note: Requires either the FULL view or REF view.
+        Might be empty even if refcount is positive.  Specific fields can
+        be empty.
         Author lists (authors, authors_auid, authors_affiliationid) may contain
-        duplicates but have been filtered of None's.
+        duplicates but None's have been filtered out.
         """
         out = []
         fields = 'position id doi title authors authors_auid '\
                  'authors_affiliationid sourcetitle publicationyear volume '\
                  'issue first last citedbycount type text fulltext'
         ref = namedtuple('Reference', fields)
-        if self._view == "REF":
-            path = ['references', 'reference']
-        else:
-            path = ['item', 'bibrecord', 'tail', 'bibliography', 'reference']
-        items = listify(chained_get(self._json, path, []))
+        items = listify(self._ref.get("reference", []))
         for item in items:
             info = item.get('ref-info', item)
             volisspag = info.get('volisspag', {}) or {}
@@ -439,6 +435,9 @@ class AbstractRetrieval(Retrieval):
                            for d in auth]
                 auids = None
                 affids = None
+                ids = listify(info['refd-itemidlist']['itemid'])
+                doi = _select_by_idtype(ids, id_type='DOI')
+                scopus_id = _select_by_idtype(ids, id_type='SGR')
             except KeyError:  # REF view parsing
                 auth = (info.get('author-list') or {}).get('author', [])
                 authors = [', '.join(filter(None, [d.get('ce:surname'),
@@ -447,18 +446,7 @@ class AbstractRetrieval(Retrieval):
                 auids = "; ".join(filter(None, [d.get('@auid') for d in auth]))
                 affs = filter(None, [d.get('affiliation') for d in auth])
                 affids = "; ".join([aff.get('@id') for aff in affs])
-            # Parse IDs
-            try:
-                ids = listify(info['refd-itemidlist']['itemid'])
-            except KeyError:
-                ids = []
-            try:
-                doi = _select_by_idtype(ids, 'DOI')[0]
-            except IndexError:
                 doi = info.get('ce:doi')
-            try:
-                scopus_id = _select_by_idtype(ids, 'SGR')[0]
-            except IndexError:
                 scopus_id = info.get('scopus-id')
             # Combine information
             new = ref(position=item.get('@id'), id=scopus_id, doi=doi,
@@ -563,8 +551,7 @@ class AbstractRetrieval(Retrieval):
 
     def __init__(self, identifier=None, refresh=False, view='META_ABS',
                  id_type=None):
-        """Class to represent the results from retrieval request from the
-        Scopus Abstract API.
+        """Interaction with the Abstract Retrieval API.
 
         Parameters
         ----------
@@ -572,8 +559,10 @@ class AbstractRetrieval(Retrieval):
             The identifier of a document.  Can be the Scoups EID, the Scopus
             ID, the PII, the Pubmed-ID or the DOI.
 
-        refresh : bool (optional, default=False)
-            Whether to refresh the cached file if it exists or not.
+        refresh : bool or int (optional, default=False)
+            Whether to refresh the cached file if it exists or not.  If int
+            is passed, cached file will be refreshed if the number of days
+            since last modification exceeds that value.
 
         id_type: str (optional, default=None)
             The type of used ID. Allowed values: None, 'eid', 'pii',
@@ -595,9 +584,9 @@ class AbstractRetrieval(Retrieval):
 
         Notes
         -----
-        The files are cached in ~/.scopus/abstract_retrieval/{view}/{identifier}.
-        In case a DOI is used as identifier, an underscore replaces the
-        forward slash in the filename.
+        The directory for cached results is `{path}/{view}/{identifier}`,
+        where `path` is specified in `~/.scopus/config.ini`.  In case
+        `identifier` is a DOI,, an underscore replaces the forward slash.
         """
         # Checks
         identifier = str(identifier)
@@ -612,13 +601,19 @@ class AbstractRetrieval(Retrieval):
             if id_type not in allowed_id_types:
                 raise ValueError('id_type parameter must be one of ' +
                                  ', '.join(allowed_id_types))
+
         # Load json
         Retrieval.__init__(self, identifier=identifier, id_type=id_type,
                            api='AbstractRetrieval', refresh=refresh, view=view)
         self._json = self._json['abstracts-retrieval-response']
         self._head = chained_get(self._json, ["item", "bibrecord", "head"], {})
-        path = ['source', 'additional-srcinfo', 'conferenceinfo', 'confevent']
-        self._confevent = chained_get(self._head, path, {})
+        conf_path = ['source', 'additional-srcinfo', 'conferenceinfo', 'confevent']
+        self._confevent = chained_get(self._head, conf_path, {})
+        if self._view == "REF":
+            ref_path = ["references"]
+        else:
+            ref_path = ['item', 'bibrecord', 'tail', 'bibliography']
+        self._ref = chained_get(self._json, ref_path, {})
 
     def __str__(self):
         """Return pretty text version of the document.
@@ -821,6 +816,9 @@ def _parse_pages(self, unicode=False):
     return pages
 
 
-def _select_by_idtype(lst, selector):
+def _select_by_idtype(lst, id_type):
     """Auxiliary function to return items matching a special idtype."""
-    return [d['$'] for d in lst if d['@idtype'] == selector]
+    try:
+        return [d['$'] for d in lst if d['@idtype'] == id_type][0]
+    except IndexError:
+        return None
