@@ -205,7 +205,7 @@ class AuthorRetrieval(Retrieval):
         return self._json['coredata']['prism:url']
 
     def __init__(self, author_id, refresh=False):
-        """Class to represent a Scopus Author query by the scopus-id.
+        """Interaction with the Author Retrieval API.
 
         Parameters
         ----------
@@ -213,13 +213,16 @@ class AuthorRetrieval(Retrieval):
             The ID of the author to search for.  Optionally expressed
             as an Elsevier EID (i.e., in the form 9-s2.0-nnnnnnnn).
 
-        refresh : bool (optional, default=False)
-            Whether to refresh the cached file (if it exists) or not.
+        refresh : bool or int (optional, default=False)
+            Whether to refresh the cached file if it exists or not.  If int
+            is passed, cached file will be refreshed if the number of days
+            since last modification exceeds that value.
 
         Notes
         -----
-        The files are cached in ~/.scopus/author_retrieval/ENHANCED/{author_id}
-        (without eventually leading '9-s2.0-').
+        The directory for cached results is `{path}/ENHANCED/{author_id}`,
+        where `path` is specified in `~/.scopus/config.ini` and `author_id`
+        is stripped of an eventually leading `'9-s2.0-'`.
         """
         # Load json
         view = "ENHANCED"  # In case Scopus adds different views in future
@@ -259,7 +262,8 @@ class AuthorRetrieval(Retrieval):
         coauthor groups.
         """
         # Get number of authors to search for
-        res = get_content(url=self.coauthor_link)
+        url = self.coauthor_link
+        res = get_content(url=url)
         data = loads(res.text)['search-results']
         N = int(data.get('opensearch:totalResults', 0))
         # Store information in namedtuples
@@ -267,10 +271,11 @@ class AuthorRetrieval(Retrieval):
         coauth = namedtuple('Coauthor', fields)
         coauthors = []
         # Iterate over search results in chunks of 25 results
-        count = 0
-        while count < N:
-            params = {'start': count, 'count': 25}
-            res = get_content(url=self.coauthor_link, params=params, accept='json')
+        count = 25
+        start = 0
+        while start < N:
+            params = {'start': start, 'count': count}
+            res = get_content(url=url, params=params, accept='json')
             data = loads(res.text)['search-results'].get('entry', [])
             # Extract information for each coauthor
             for entry in data:
@@ -288,11 +293,11 @@ class AuthorRetrieval(Retrieval):
                     country=aff.get('affiliation-country'))
                 coauthors.append(new)
             count += 25
-        return coauthors
+        return coauthors or None
 
     def get_documents(self, subtypes=None, **kwds):
-        """Return list of author's publications using ScopusSearch, which
-        fit a specified set of document subtypes.
+        """Return list of the author's publications using a ScopusSearch()
+        query, where publications may fit specified set of document subtypes.
 
         Parameters
         ----------
@@ -305,21 +310,22 @@ class AuthorRetrieval(Retrieval):
         Returns
         -------
         results : list of namedtuple
-            The same type of results returned from any ScopusSearch.
+            The same type of results returned from any ScopusSearch().
         """
-        search = ScopusSearch('au-id({})'.format(self.identifier), **kwds)
+        s = ScopusSearch('AU-ID({})'.format(self.identifier), **kwds)
         if subtypes:
-            return [p for p in search.results if p.subtype in subtypes]
+            return [p for p in s.results if p.subtype in subtypes]
         else:
-            return search.results
+            return s.results
 
     def get_document_eids(self, *args, **kwds):
-        """Return list of EIDs of author's publications using ScopusSearch."""
-        search = ScopusSearch('au-id({})'.format(self.identifier),
-                              *args, **kwds)
-        return search.get_eids()
+        """Return list of EIDs of the author's publications using
+        a ScopusSearch() query.
+        """
+        s = ScopusSearch('AU-ID({})'.format(self.identifier), *args, **kwds)
+        return s.get_eids()
 
-    def estimate_uniqueness(self, query=None, refresh=False, download=False):
+    def estimate_uniqueness(self, query=None, **kwds):
         """Estimate how unqiue a profile is by get the number of
         matches of an AuthorSearch for this person.
 
@@ -332,11 +338,8 @@ class AuthorRetrieval(Retrieval):
             "SUBJAREA()" OR "AF-ID() AND SUBJAREA()".  For details see
             https://dev.elsevier.com/tips/AuthorSearchTips.htm.
 
-        refresh : bool (optional, default=False)
-            Whether to refresh the cached file (if it exists) or not.
-
-        download : bool (optional, defaul=False)
-            Whether to cached the file or not.
+        **kwds : dict-like
+            Parameters to be passed on to ScopusSearch().
 
         Returns
         -------
@@ -350,5 +353,5 @@ class AuthorRetrieval(Retrieval):
         if not query:
             query = "AUTHLAST({}) AND AUTHFIRST({})".format(
                 self.surname, self.given_name)
-        s = AuthorSearch(query, download=download, refresh=refresh)
+        s = AuthorSearch(query, **kwds)
         return s.get_results_size()
